==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityFieldDelegate.java <==
package org.keycloak.models.map.events;
public class MapAuthEventEntityFieldDelegate extends org.keycloak.models.map.events.MapAuthEventEntity.AbstractAuthEventEntity implements org.keycloak.models.map.events.MapAuthEventEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> entityFieldDelegate;
    public MapAuthEventEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.events.EventType getType() {
        return (org.keycloak.events.EventType) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(org.keycloak.events.EventType p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSessionId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setSessionId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getError() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR);
    }
    @SuppressWarnings("unchecked") @Override public void setError(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getDetails() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS);
    }
    @SuppressWarnings("unchecked") @Override public void setDetails(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityFieldDelegate.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthEventEntityFieldDelegate extends org.keycloak.models.map.events.MapAuthEventEntity.AbstractAuthEventEntity implements org.keycloak.models.map.events.MapAuthEventEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> entityFieldDelegate;
    public MapAuthEventEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAuthEventEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.events.EventType getType() {
        return (org.keycloak.events.EventType) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(org.keycloak.events.EventType p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSessionId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setSessionId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getError() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR);
    }
    @SuppressWarnings("unchecked") @Override public void setError(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getDetails() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS);
    }
    @SuppressWarnings("unchecked") @Override public void setDetails(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS, p0);
    }
}
